perf: load presets in parallel, cutting preset load time by over 60% (#15943)

Co-authored-by: Rodrigo Faselli <162915171+RF47@users.noreply.github.com>
This commit is contained in:
Kris Austin
2026-09-29 18:13:44 -03:00
committed by GitHub
co-authored by Rodrigo Faselli
parent 2769b12ce7
commit f5679ad343
17 changed files with 2038 additions and 637 deletions
File diff suppressed because it is too large Load Diff